pg_update_stmt: Update helper (PATCH)

Description Usage Arguments Details

Description

For updating informaiton by supplying the path to the table, and the value to update.

Usage

1
pg_update_stmt(table, dat_obj, primary_key = NULL, value = NULL)

Arguments

dat_obj

data to pass to quick books

primary_key

data 'primary key = dat_object$fullName'

value

field to define as the primary key

path

to the object to update

Details

This is geared towards mostly updating

//TODO update the primary key and the column name as separate things


Cloud9Smart/postgresUtils documentation built on Sept. 20, 2020, 12:43 a.m.