Description Usage Arguments Details
For updating informaiton by supplying the path to the table, and the value to update.
1 | pg_update_stmt(table, dat_obj, primary_key = NULL, value = NULL)
|
dat_obj |
data to pass to quick books |
primary_key |
data 'primary key = dat_object$fullName' |
value |
field to define as the primary key |
path |
to the object to update |
This is geared towards mostly updating
//TODO update the primary key and the column name as separate things
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.